@@ -24,7 +24,7 @@ class Client():
         self.out = self.arg.output
         self.all_rules = self.arg.all
         self.all_in_one = None
-        self.off_webbrowser = None
+        self.display_html = None
         self.isatty = sys.stdout.isatty()
         self.show_failed_rules = False
         self.show_not_selected_rules = False
@@ -33,6 +33,7 @@ class Client():
         self.parts = self.get_src('parts')
         self.START_OF_FILE_NAME = 'graph-of-'
         self.date = str(datetime.now().strftime("-%d_%m_%Y-%H_%M_%S"))
+        self.verbose = self.arg.verbose
 
     def _get_message(self):
         MESSAGES = {
@@ -72,15 +73,19 @@ class Client():
             self.search_rules_id()) if self.show_failed_rules else self.search_rules_id()
 
     def get_list_of_lines(self):
-        lines = ['== The Rule IDs ==']
+        lines = ['== The Rule ID regular expressions ==']
         for rule in self.get_list_of_matched_rules():
-            lines.append("'" + rule + r'\b' + "'")
+            lines.append("^" + rule + "$")
         if self.show_not_selected_rules:
             for line in self.get_lines_of_wanted_not_selected_rules():
                 lines.append(line)
         lines.append(
-            "You haven't got installed inquirer lib. "
-            "Please copy id rule with you want use and put it in command")
+            "Interactive rule selection is not available,"
+            " because inquirer is not installed."
+            " Copy id of the rule you want to visualize and"
+            " paste it into a command with regular"
+            " expression characters(^$).\n"
+            "Alternatively, use the --all or --all-in-one arguments.")
         return lines
 
     def get_selection_rules(self):
@@ -153,7 +158,7 @@ class Client():
                 self.out,
                 self.START_OF_FILE_NAME + rule + '.html')
         return os.path.join(
-            os.getcwd(),
+            tempfile.gettempdir(),
             self.START_OF_FILE_NAME + rule + '.html')
 
     def get_src(self, src):
@@ -161,7 +166,8 @@ class Client():
         return str(os.path.join(_dir, src))
 
     def _build_and_save_html(self, dict_oval_trees, src, rules, out):
-        builder = BuilderHtmlGraph(self.parts, self.off_webbrowser)
+        builder = BuilderHtmlGraph(
+            self.parts, self.display_html, self.verbose)
         builder.save_html_and_open_html(dict_oval_trees, src, rules, out)
 
     def _prepare_data(self, rules, dict_oval_trees, out):
@@ -206,6 +212,11 @@ class Client():
             help=(
                 "Do not display passing tests for better orientation in"
                 " graphs that contain a large amount of nodes.(Not implemented)"))
+        self.parser.add_argument(
+            '--verbose',
+            action="store_true",
+            default=False,
+            help="Displays details about the results of the running command.")
         self.parser.add_argument(
             '-o',
             '--output',
